"use client";

import React, { useEffect, useState } from 'react';
import { Swiper, SwiperSlide } from 'swiper/react';
import 'swiper/css';
import 'swiper/css/pagination';
import 'swiper/css/navigation';
import { Pagination, Autoplay } from 'swiper/modules';
import Link from 'next/link'; // Import Link from Next.js

const networkIds = [213, 49, 1024, 2739, 174, 453, 2552]; // List of network IDs

const NetworkSlider: React.FC = () => {
  const [networks, setNetworks] = useState<any[]>([]);

  useEffect(() => {
    const fetchNetworks = async () => {
      try {
        const responses = await Promise.all(
          networkIds.map((id) =>
            fetch(
              `https://api.themoviedb.org/3/network/${id}?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
            ).then((res) => res.json())
          )
        );
        setNetworks(responses);
      } catch (error) {
        console.error('Failed to fetch network data:', error);
      }
    };

    fetchNetworks();
  }, []);

  return (
    <div className="relative mt-12 animate-fadeInUp">
      <div className="flex justify-between items-center mb-4 mx-4 animate-slideInLeft">
        <h2 className="text-2xl font-bold text-white text-left md:text-2xl sm:text-xl">
          Popular Networks
        </h2>
      </div>
      <Swiper
        modules={[Pagination, Autoplay]}
        spaceBetween={10}
        slidesPerView={3} // Default for mobile
        breakpoints={{
          640: {
            slidesPerView: 3, // 3 slides per view on mobile
          },
          768: {
            slidesPerView: 5, // 5 slides per view on tablets
          },
          1024: {
            slidesPerView: 6, // 6 slides per view on PC
          },
        }}
        loop={true}
        autoplay={{ delay: 3000 }}
        pagination={{
          clickable: true,
          bulletClass: 'swiper-pagination-bullet',
          bulletActiveClass: 'swiper-pagination-bullet-active',
        }}
        className="mySwiper"
      >
        {networks.map((network) => (
          <SwiperSlide key={network.id}>
            <Link href={`/network?id=${network.id}`} passHref> {/* Navigate with query parameter */}
              <div className="p-4 bg-white rounded-lg shadow-lg flex items-center justify-center hover:scale-105 transition-transform duration-300 ease-in-out cursor-pointer">
                <img
                  src={`https://image.tmdb.org/t/p/original${network.logo_path}`}
                  alt={network.name}
                  className="h-12"
                />
              </div>
            </Link>
          </SwiperSlide>
        ))}
      </Swiper>
      <div className="mt-4 custom-pagination swiper-pagination"></div>
      <style jsx global>{`
        .swiper-pagination {
          position: relative;
          margin-top: 10px;
        }
        .swiper-pagination-bullet {
          background-color: rgba(255, 255, 255, 0.4);
        }
        .swiper-pagination-bullet-active {
          background-color: red;
        }

        @keyframes fadeInUp {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes slideInLeft {
          from {
            opacity: 0;
            transform: translateX(-20px);
          }
          to {
            opacity: 1;
            transform: translateX(0);
          }
        }

        .animate-fadeInUp {
          animation: fadeInUp 1s ease-in-out;
        }

        .animate-slideInLeft {
          animation: slideInLeft 1s ease-in-out;
        }
      `}</style>
    </div>
  );
};

export default NetworkSlider;
